@@ -126,8 +126,7 @@ class Reliquary:
             with open(input_settings, "r") as json_filehandle:
                 json_settings = json.load(json_filehandle)
         except Exception as e:
-            print("E0000: Error Loading Settings File: " + str(e))
-            exit()
+            exit("E0000: Error Loading Settings File: " + str(e))
 
         try:
             # Let's start with basic global settings
@@ -206,16 +205,24 @@ class Reliquary:
                     + str(response_code)
                     + " "
                     + self.get_http_error_code(response_code)
+                    + ": "
+                    + do_api_delete_url
                 )
                 return do_api_delete_r.text
             else:
                 print("EA999: Unhandled HTTP Error " + str(response_code) + "!")
-                exit()  # interpet the error, then close out so we don't have to put all the rest of our code in an except statement
         except requests.RequestException as requests_exception:
             print(requests_exception)
         except Exception as e:
-            print("E1002: Unhandled Requests exception! " + str(e))
-            exit()
+            print(
+                "E1002: Unhandled Requests exception! "
+                + str(e)
+                + " with endpoint "
+                + do_api_delete_url
+                + "and response "
+                + do_api_delete_r.text
+            )
+            print(str(e))
 
     # Do API GET, using basic credentials
     def do_api_get(self, do_api_uri, do_api_dryrun=False, do_api_json_pretty=False):
@@ -260,16 +267,24 @@ class Reliquary:
                     + str(response_code)
                     + " "
                     + self.get_http_error_code(response_code)
+                    + ": "
+                    + do_api_get_url
                 )
                 return do_api_get_r.text
             else:
                 print("EA999: Unhandled HTTP Error " + str(response_code) + "!")
-                exit()  # interpet the error, then close out so we don't have to put all the rest of our code in an except statement
         except requests.RequestException as requests_exception:
             print(requests_exception)
         except Exception as e:
-            print("E1002: Unhandled Requests exception! " + str(e))
-            exit()
+            print(
+                "E1002: Unhandled Requests exception! "
+                + str(e)
+                + " with endpoint "
+                + do_api_get_url
+                + "and response "
+                + do_api_get_r.text
+            )
+            print(str(e))
 
     # Do API POST, using basic credentials
     def do_api_pass(
@@ -316,12 +331,27 @@ class Reliquary:
                     return self.json_prettyprint(do_api_r.text)
                 else:
                     return do_api_r.text  # if HTTP status is good, save response
+            # If it doesn't have a payload, type will be boolean
+            elif not do_api_dryrun and type(do_api_payload) is bool:
+                do_api_r = requests.request(
+                    do_api_verb,
+                    url=do_api_url,
+                    headers=self.cogitation_headers,
+                    verify=self.cogitation_certvalidation,
+                    auth=(self.cogitation_username, self.cogitation_password),
+                )
+                # We'll be discarding the actual `Response` object after this, but we do want to get HTTP status for erro handling
+                response_code = do_api_r.status_code
+                do_api_r.raise_for_status()  # trigger an exception before trying to convert or read data. This should allow us to get good error info
+                if do_api_json_pretty:
+                    return self.json_prettyprint(do_api_r.text)
+                else:
+                    return do_api_r.text  # if HTTP status is good, save response
             else:
                 do_api_dryrun_report = {
                     "do_api_get_headers": self.cogitation_headers,
-                    "do_api_get_url": do_api_url,
+                    "do_api_url": do_api_url,
                     "do_api_verb": do_api_verb,
-                    "do_api_payload": json.loads(do_api_payload),
                 }
                 print(self.json_prettyprint(do_api_dryrun_report))
         except requests.Timeout:
@@ -337,16 +367,24 @@ class Reliquary:
                     + str(response_code)
                     + " "
                     + self.get_http_error_code(response_code)
+                    + ": "
+                    + do_api_url
                 )
                 return do_api_r.text
             else:
                 print("EA999: Unhandled HTTP Error " + str(response_code) + "!")
-                exit()  # interpet the error, then close out so we don't have to put all the rest of our code in an except statement
         except requests.RequestException as requests_exception:
             print(requests_exception)
         except Exception as e:
-            print("E1002: Unhandled Requests exception! " + str(e))
-            exit()
+            print(
+                "E1002: Unhandled Requests exception! "
+                + str(e)
+                + " with endpoint "
+                + do_api_url
+                + "and response "
+                + do_api_r.text
+            )
+            print(str(e))
 
     # Executor of the API calls.
     # Takes optional arguments (variables, payload) depending on which method is used
@@ -547,8 +585,7 @@ class Reliquary:
             with open(filename, "r") as json_filehandle:
                 return json.load(json_filehandle)
         except Exception as e:
-            print("E0000: Error Loading Settings File " + filename + ": " + str(e))
-            exit()
+            exit("E0000: Error Loading Settings File " + filename + ": " + str(e))
 
     def get_json_file_or_string(self, input):
         # Recursive method to return a dictionary even if we're passed a dictionary
